/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Index - IndexingService.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.index.indexing;

import ch.unige.solidify.IndexProperties;
import ch.unige.solidify.exception.SolidifyRuntimeException;
import ch.unige.solidify.model.index.IndexMetadata;
import ch.unige.solidify.service.IndexResourceService;

public abstract class IndexingService<T extends IndexMetadata> extends IndexResourceService<String, T> {

  private String indexPrefix;

  protected IndexingService(IndexProperties indexProperties) {
    this.indexPrefix = indexProperties.getIndexPrefix();
  }

  protected abstract T getMetadataObject();

  protected void checkIndex(String indexName) {
    if (!indexName.startsWith(this.indexPrefix)) {
      throw new SolidifyRuntimeException("Invalid index name '" + indexName + "' must start with '" + this.indexPrefix + "'");
    }
  }

}
